@@ -1,5 +1,5 @@
 //
-// Copyright 2010-2011 Ettus Research LLC
+// Copyright 2010-2012 Ettus Research LLC
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #define HB_PA_TXIO               LB_PA_OFF_TXIO
 #define LB_PA_TXIO               HB_PA_OFF_TXIO
 #define TX_ENB_TXIO              TX_EN_TXIO
-#define TX_DIS_TXIO              0
+#define TX_DIS_TXIO              (HB_PA_OFF_TXIO | LB_PA_OFF_TXIO)
 #define AD9515DIV_3_TXIO         AD9515DIV_TXIO
 #define AD9515DIV_2_TXIO         0
 
